@@ -246,26 +246,6 @@ class ComplexSTFTDiscriminator(nn.Module):
 
         return complex_logits_abs, intermediates
 
-# learned EMA blocks
-
-class MultiHeadEMABlock(nn.Module):
-    def __init__(
-        self,
-        dim,
-        **kwargs
-    ):
-        super().__init__()
-        self.prenorm = nn.LayerNorm(dim)
-        self.mhema = MultiHeadedEMA(dim = dim, **kwargs)
-
-    def forward(self, x):
-        residual = x.clone()
-        x = rearrange(x, 'b c n -> b n c')
-        x = self.prenorm(x)
-        x = self.mhema(x)
-        x = rearrange(x, 'b n c -> b c n')
-        return x + residual
-
 # sound stream
 
 class Residual(nn.Module):
@@ -380,7 +360,8 @@ class SoundStream(nn.Module):
         attn_window_size = 128,
         attn_dim_head = 64,
         attn_heads = 8,
-        attn_depth = 1
+        attn_depth = 1,
+        attn_xpos_scale_base = None
     ):
         super().__init__()
 
@@ -418,6 +399,7 @@ class SoundStream(nn.Module):
             dim_head = attn_dim_head,
             heads = attn_heads,
             window_size = attn_window_size,
+            xpos_scale_base = attn_xpos_scale_base,
             prenorm = True,
             causal = True
         )
